==> molds_0.2.0.orig.tar.gz: molds-0.2.0/src/third_parties/rEnumStr/rEnumStr.h <==
/*---------------------------------------------------------------------------
    Copyright (C) 2004  rage2050  rage2050@mail.goo.ne.jp
    ({MD5/UTF-8: ab93b9b4f0bec5870b90ceb98d08b7e2)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
---------------------------------------------------------------------------*/

//  CZX GPL ɂĂ܂AȂ̂͂čxȃeNĂ킯ł
// Ȃ̂ŁÃt@Cû܂܁vĝłȂ΁Al̃eN
// PROPRIETARYȃR[hɓ邱Ƃ͉\Ƃ܂B
// ȂƂ͂PROPRIETARYȃR[h̏L҂i肵܂B
// (̐l̃eNƐ肵悤ƂāArEnumStr.h gĂ鑼̐l
//  icȂǂƂȂƂȂ!)

//---------------------------------------------------------------------------
/** @file
    @brief enum ɑΉ镶𓯎ɒ`}NQ

enum ƁAɑΉ镶Aɒ`邱Ƃł܂B
̂߁Aenum ƕ񂪁AYH葫ȂAƂ~XhƂł܂B

<hr>

@section whatis ֗Ȃ?

@subsection old_problem ]̕@̌_

enum 萔ƂɑΉ镶`ƂAʂ͈ȉ̂悤ɏ܂BF̔ԍƖO`łB

@code
  //////////////////// wb_t@C mycolor.h ////////////////////
  #ifndef MYCOLOR_H_INCLUDE
  #define MYCOLOR_H_INCLUDE
  enum MyColor { ///< F\ enum
    C_BLACK,
    C_BLUE,
    C_RED,
    C_GREEN,
    C_WHITE,
  };
  extern char * gMyColor[C_MAX]; ///< FenumɑΉ
  void DrawCircleWithColor(MyColor c, int x, int y, int r);///< `cȂ
  #endif //MYCOLOR_H_INCLUDE
@endcode

@code
  //////////////////// \[Xt@C mycolor.cpp ////////////////////
  #include "mycolor.h"
  char * gMyColor[C_MAX] = {
    "", // C_BLACK
    "", // C_BLUE
    "", // C_RED
    "", // C_GREEN
    "", // C_WHITE
  };
@endcode

A̕@ɂ́AenumǉE폜EύX邽тɁAΉ镶 <B>YꂸɁEԈႦ</B> ɏCȂ΂ȂȂAƂ_܂B

rEnumStr.h gƁAenum ƕ𓯎ɒ`邱ƂłāAenum ǉE폜EύXƂɕCYꂽԈႦ肷邱Ƃh܂B

<hr>

@subsection improved rEnumStr.h gƂǂȂ?

قǂ̐F̔ԍƖÓ̗Aȉ̂悤ɏ܂B

@code
  //////////////////// wb_t@C mycolor.h ////////////////////
  //---- ^IȂ܂Ȃ ----
  #ifndef MYCOLOR_DEFINED
  #define MYCOLOR_DEFINED
  #ifndef RENUMSTR_BODY
  #define RENUMSTR_BODY 0
  #endif
  #include "rEnumStr.h"
  //---- F̔ԍƕ` ----
  RENUMSTR_BEGIN( MyColor, MyColorStr )
    RENUMSTR( C_BLACK,  "" )
    RENUMSTR( C_BLUE,   "" )
    RENUMSTR( C_RED,    "" )
    RENUMSTR( C_GREEN,  "" )
    RENUMSTR( C_WHITE,  "" )
  RENUMSTR_END()
  #endif //MYCOLOR_DEFINED
  //---- 畁ʂ̃wb_t@C ----
  #ifndef MYCOLOR_H_INCLUDE
  #define MYCOLOR_H_INCLUDE
  void DrawCircleWithColor(MyColor c, int x, int y, int r);///< `cȂ
  #endif //MYCOLOR_H_INCLUDE
@endcode

@code
  //////////////////// \[Xt@C mycolor.cpp ////////////////////
  #include "mycolor.h"
  #undef MYCOLOR_DEFINED        // 荞ނ߂
  #define RENUMSTR_BODY 1       // ݒς
  #include "mycolor.h"          // xinclude܂B
@endcode



<hr>

@section usage g

@subsection intro gn߂̂܂Ȃ

@code
  //////////////////// wb_t@C mycolor.h ////////////////////
  //---- ^IȂ܂Ȃ ----
  #ifndef MYCOLOR_DEFINED
  #define MYCOLOR_DEFINED
  #ifndef RENUMSTR_BODY
  #define RENUMSTR_BODY 0
  #endif
  #include "rEnumStr.h"
    :
@endcode

GɌ܂ArEnumStr.h gȂƂ͂̕RsyāA MYCOLOR_DEFINED }N̖OKɒu邾ővłB


@subsection main `Ă镔

@code
    :
  //---- F̔ԍƕ` ----
  RENUMSTR_BEGIN( MyColor, MyColorStr )
    RENUMSTR( C_BLACK,  "" )
    RENUMSTR( C_BLUE,   "" )
    RENUMSTR( C_RED,    "" )
    RENUMSTR( C_GREEN,  "" )
    RENUMSTR( C_WHITE,  "" )
  RENUMSTR_END()
  #endif //MYCOLOR_DEFINED
@endcode

ŏ RENUMSTR_BEGIN( enum^ , ֐ ) Œ`JnAŌ RENUMSTR_END() Œ`I܂B

̊Ԃ RENUMSTR( enum ,  ) ׂāAenum ƕ𓯎ɒ`܂B



@subsection cpp `̉镔

@code
  //////////////////// \[Xt@C mycolor.cpp ////////////////////
  #include "mycolor.h"
  #undef MYCOLOR_DEFINED        // 荞ނ߂
  #define RENUMSTR_BODY 1       // ݒς
  #include "mycolor.h"          // xinclude܂B
@endcode

1ڂ include  enum MyColor ^Ƃ̗vf C_BLACK, C_BLUE, ... `܂B1ڂ include ł RENUMSTR_BODY }N 0 ɂȂ邽߁A mycolor.h ȉ̂悤ɓWJ邩łB
@code
  ////////// 1ڂ͂̂悤ɓWJ //////////
  enum MyColor {
    C_BLUE,
    C_RED,
    C_GREEN,
    C_WHITE,
  };
  const char * MyColorStr(int);
@endcode

2ڂ include ŁAenumɑΉ镶Ԃ֐ MyColorStr() ܂B2ڂ mycolor.cpp Ń}N RENUMSTR_BODY  1 ɒ`Ă̂ŁA mycolor.h WJƁAȉ̂悤Ȋ֐ MyColorStr() ܂B

@code
  ////////// 2ڂ͂̂悤ɓWJ //////////
  const char * MyColorStr(int i)
  {
    switch (i) {
    default: return "???";
    case C_BLUE: return "";
    case C_RED: return "";
    case C_GREEN: return "";
    case C_WHITE: return "";
    }
  }
@endcode

@subsection invoke enum╶oɂ

mycolor.h }NWJ enum `ƕ擾֐ MyColorStr() ̐錾łĂ̂ŁA include 邾ŊȒP enum g悤ɂȂ܂B

@code
  //////////////////// C[` main.cpp ////////////////////
  #include <stdio.h>
  #include "mycolor.h"
  int main(int, char**)
  {
    MyColor c = C_BLUE;
    printf( "%d = %s\n", c, MyColorStr(c) );
    return 0;
  }
@endcode



<hr>

@attention

̎̒` On/Off  enumƂɐݒ肷邽߂ɁA
RENUMSTR_BODYFLAG }Ńu[JvɂȂĂ܂B
(rEnumStr.hinclude邽т \#undef RENUMSTR_BODYFLAG )
 RENUMSTR_BODYFLAG }ŃA<B>vWFNgŜŐݒ肷̂ł͂Ȃ</B>A
\#include "rEnumStr.h" gтɂ̒OŒ`ĂB
vWFNgݒ RENUMSTR_BODYFLAG `Ɨ\zŐɂȂ܂B

RENUMSTR_BODYFLAG }N͕Ku\[Xt@Cv \#include "rEnumStr.h" 
OŒ`ĂBwb_t@CvWFNgݒŒ`
RpCG[ɂȂ܂B

*/
//---------------------------------------------------------------------------
//#ifndef rEnumStrH
//#define rEnumStrH



//---------------------------------------------------------------------------
#ifndef RENUMSTR_BODY //{
#error #include "rEnumStr.h" ̑O RENUMSTR_BODY `Ă܂

// doxygenpRg͂ɏȂƃ_? {

/// enum\̒`JnB
  /** @param nameEnum          enum^̖O
      @param nameStr           擾֐̖O

      \IK RENUMSTR_END() uĂB
   */
#define RENUMSTR_BEGIN(nameEnum, nameStr)

  /** @brief enumƕЂƂB
      @param idEnum            enum萔
      @param idStr             enumɑΉÂ镶
   */
#define RENUMSTR(idEnum, idStr)

  /** @brief enumЂƂAenum̂̂̕蓖ĂB
      @param idEnum            enum萔
   */
#define RENUMSTR1(idEnum)

  /** @brief enumɒlݒ肵AenumƕΉB
      @param idEnum            enum萔
      @param val               enumɐݒ肷l
      @param idStr             enumɑΉÂ镶
  */
#define RENUMSTR_LET(idEnum, val, idStr)

  /** @brief enum̒ɎRȈsB
      @param line              s̓e

      enum萔ɕʖȂǂɎg܂B
  */
#define RENUMSTR_ENUMONLY(line)

  /** @brief enum\IB

      \IK RENUMSTR_END() uĂB
   */
#define RENUMSTR_END()

  /** @brief [[U`] [K{] rEnumStr.h̓샂[hݒB

      rEnumStr.h gwb_/\[Xt@Cł́A
      #include "rEnumStr.h" ̑OɕK̃}N`ĂB

      - 0 ɂƁAenum錾ƕ擾֐̃vg^Cv錾𐶐܂B
        (wb_[h)
      - 1 ɂƁA擾֐̎̂𐶐܂B
        (\[X[h)
   */
#define RENUMSTR_BODY

  /** @brief [[U`] ̂̒`On/OffB

      \[Xt@C #include "rEnumStr.h" ̒Oł̃}N
      `ƁÂ̒` On/Off ł܂B
      [Xłł͕`ȂAȂǂ̗prɎg܂B

      - 0 ɂƁA𐶐܂B
      - 1 ɂƁA𐶐܂B
   */
#define RENUMSTR_BODYFLAG

// doxygen }
#else //}{



//---------------------------------------------------------------------------
#if RENUMSTR_BODY //{

#undef RENUMSTR_BEGIN
#undef RENUMSTR
#undef RENUMSTR1
#undef RENUMSTR_LET
#undef RENUMSTR_ENUMONLY
#undef RENUMSTR_END

#ifndef RENUMSTR_BODYFLAG
/// ̎̂`邩? ([J)
/** 񂪃fobOpł胊[Xłł͒`ȂȂǂ̏ꍇA
    [Xł̂Ƃ #define RENUMSTR_BODYFLAG 0 ɂ邱Ƃ
    `Ȃ悤ɂł܂B
 */
#define RENUMSTR_BODYFLAG 1
#endif

#ifndef RENUMSTR_DEFAULTSTR
/// enum͈͊ÔƂdefault ([J)
/** 擾֐ɔ͈͊ÖnꂽƂɕԂw肵܂B
 */
#define RENUMSTR_DEFAULTSTR "???"
#endif


#define RENUMSTR_BEGIN(nameEnum, nameStr)          const char *nameStr(int i) { \
                                                    switch (i) { \
                                                    default: return RENUMSTR_DEFAULTSTR;
#if RENUMSTR_BODYFLAG //{
#define RENUMSTR(idEnum, idStr)                case idEnum: return idStr;
#define RENUMSTR1(idEnum)                       case idEnum: return #idEnum;
#define RENUMSTR_LET(idEnum, val, idStr)        case idEnum: return idStr;
#else //}{
#define RENUMSTR(idEnum, idStr)
#define RENUMSTR1(idEnum)
#define RENUMSTR_LET(idEnum, val, idStr)
#endif //}
#define RENUMSTR_ENUMONLY(line)

#define RENUMSTR_END()                               } \
                                                  }

//---------------------------------------------------------------------------
#else //}{ !RENUMSTR_BODY

#undef RENUMSTR_BEGIN
#undef RENUMSTR
#undef RENUMSTR1
#undef RENUMSTR_LET
#undef RENUMSTR_ENUMONLY
#undef RENUMSTR_END

// RENUMSTR_BODYFLAG Ԉăwb_Œ`Ƃ̓G[ɂ
// vWFNgݒŒ`ƂG[ɂȂႤc
#ifdef RENUMSTR_BODYFLAG
#error RENUMSTR_BODYFLAG ́u\[Xt@CvŒ`Ă
#endif

#define RENUMSTR_BEGIN(nameEnum, nameStr)          const char *nameStr(int); \
                                                  enum nameEnum {
#define RENUMSTR(idEnum, idStr)                idEnum,
#define RENUMSTR1(idEnum)                       idEnum,
#define RENUMSTR_LET(idEnum, val, idStr)        idEnum=val,
#define RENUMSTR_ENUMONLY(line)                      line,
#define RENUMSTR_END()                             };

//---------------------------------------------------------------------------
#endif //}


//#undef RENUMSTR_DEFAULTSTR
#undef RENUMSTR_BODYFLAG
#undef RENUMSTR_BODY
//---------------------------------------------------------------------------
#endif //}
//#endif

==> molds_0.3.1.orig.tar.gz: molds-0.3.1/src/third_parties/rEnumStr/rEnumStr.h <==
//************************************************************************//
// Copyright (C) 2011-2013 Mikiya Fujii                                   // 
//                                                                        // 
// This file is part of MolDS.                                            // 
// This file is a modified version of the original rEnumStr.h.            // 
// The modification is carried in 2013/03/01 to delete Japanese.          // 
// The original rEnumStr.h is distributed at                              //
// http://www.geocities.jp/rage2050a/rEnumStr/rEnumStr.html               //
// The copyright of the original rEnumStr.h is shown below.               //
//                                                                        //
// MolDS is free software: you can redistribute it and/or modify          // 
// it under the terms of the GNU General Public License as published by   // 
// the Free Software Foundation, either version 3 of the License, or      // 
// (at your option) any later version.                                    // 
//                                                                        // 
// MolDS is distributed in the hope that it will be useful,               // 
// but WITHOUT ANY WARRANTY; without even the implied warranty of         // 
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          // 
// GNU General Public License for more details.                           // 
//                                                                        // 
// You should have received a copy of the GNU General Public License      // 
// along with MolDS.  If not, see <http://www.gnu.org/licenses/>.         // 
//************************************************************************//

/*---------------------------------------------------------------------------
    Copyright (C) 2004  rage2050  rage2050@mail.goo.ne.jp
    (name MD5/UTF-8: ab93b9b4f0bec5870b90ceb98d08b7e2)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
---------------------------------------------------------------------------*/

//---------------------------------------------------------------------------
//#ifndef rEnumStrH
//#define rEnumStrH

//---------------------------------------------------------------------------
#ifndef RENUMSTR_BODY //{
#error RENUMSTR_BODY should be defined before #include "rEnumStr.h"
#define RENUMSTR_BEGIN(nameEnum, nameStr)
#define RENUMSTR(idEnum, idStr)
#define RENUMSTR1(idEnum)
#define RENUMSTR_LET(idEnum, val, idStr)
#define RENUMSTR_ENUMONLY(line)
#define RENUMSTR_END()
#define RENUMSTR_BODY
#define RENUMSTR_BODYFLAG

// doxygen }
#else //}{

//---------------------------------------------------------------------------
#if RENUMSTR_BODY //{

#undef RENUMSTR_BEGIN
#undef RENUMSTR
#undef RENUMSTR1
#undef RENUMSTR_LET
#undef RENUMSTR_ENUMONLY
#undef RENUMSTR_END

#ifndef RENUMSTR_BODYFLAG
#define RENUMSTR_BODYFLAG 1
#endif
#ifndef RENUMSTR_DEFAULTSTR
#define RENUMSTR_DEFAULTSTR "???"
#endif


#define RENUMSTR_BEGIN(nameEnum, nameStr)          const char *nameStr(int i) { \
                                                    switch (i) { \
                                                    default: return RENUMSTR_DEFAULTSTR;
#if RENUMSTR_BODYFLAG //{
#define RENUMSTR(idEnum, idStr)                case idEnum: return idStr;
#define RENUMSTR1(idEnum)                       case idEnum: return #idEnum;
#define RENUMSTR_LET(idEnum, val, idStr)        case idEnum: return idStr;
#else //}{
#define RENUMSTR(idEnum, idStr)
#define RENUMSTR1(idEnum)
#define RENUMSTR_LET(idEnum, val, idStr)
#endif //}
#define RENUMSTR_ENUMONLY(line)

#define RENUMSTR_END()                               } \
                                                  }

//---------------------------------------------------------------------------
#else //}{ !RENUMSTR_BODY

#undef RENUMSTR_BEGIN
#undef RENUMSTR
#undef RENUMSTR1
#undef RENUMSTR_LET
#undef RENUMSTR_ENUMONLY
#undef RENUMSTR_END

#ifdef RENUMSTR_BODYFLAG
#error RENUMSTR_BODYFLAG should be difeined in the source files
#endif

#define RENUMSTR_BEGIN(nameEnum, nameStr)          const char *nameStr(int); \
                                                  enum nameEnum {
#define RENUMSTR(idEnum, idStr)                idEnum,
#define RENUMSTR1(idEnum)                       idEnum,
#define RENUMSTR_LET(idEnum, val, idStr)        idEnum=val,
#define RENUMSTR_ENUMONLY(line)                      line,
#define RENUMSTR_END()                             };

//---------------------------------------------------------------------------
#endif //}

//#undef RENUMSTR_DEFAULTSTR
#undef RENUMSTR_BODYFLAG
#undef RENUMSTR_BODY
//---------------------------------------------------------------------------
#endif //}
//#endif
